
/*
 * serverSide.c *
 *
 * This file is called by the GUI as it initialises. The commands are to link
 * in any features required by the control API. It is actually very general, 
 * and it is theoretically possible to add completely new command sets to SLab,
 * and then call those commands from the UserSLab.tcl file in the libtcl 
 * directory.
 *
 * Basically it makes the SLab gui fully extensible. Similar operations are
 * likely to take place with the mixing engine if anybody is interested.
 */

#include <tk.h>

/*
 * This will be called by components of the TCL code for any events related to
 * the control API.
 */
int FE_controlAPI();

#define GUI_DEBUG_EXT (0x4 << 20)

/*
 * controlAPIinit():
 * We should open a socket, make it non-blocking, and put it into listen mode
 * initially for just one connection. Checks for new connections are going to
 * be busy, but we will try and configure SIGUSR2 for these events.
 *
 * This routines is called during the mixslab initialisation routines, after
 * loading the global parameters and mix parameters for a song.
 */
controlAPIinit(interp)
Tcl_Interp *interp;
{
printf("controlAPIinit\n");
	/*
	 * Add a command to the GUI. Note that the command is below, but actually
	 * does nothing at the moment.
	 */
	Tcl_CreateCommand(interp, "controlAPI", FE_controlAPI,
		Tk_MainWindow(interp), NULL);

	initInterpreters();
	initLimits();

	/*
	 * Open the oscilloscpe socket.
	 */
	open_remote_socket("oscilloscope", 5001, 1, -1);
	/*
	 * Get our socket connection, found in socketToolKit.c
	 */
	return(open_remote_socket("slab", 5000, 1, -1));
}

int FE_controlAPI(clientData, interp, argc, argv)
ClientData clientData;
Tcl_Interp *interp;
int argc;
char **argv;
{
	/*
	 * Since this is going to be provided as end  user code, we need a check
	 * debug option that understands internal data structures.
	 */
	log_entry(GUI_DEBUG_EXT, "FE_controlAPI(%s)\n", argv[1]);

	/*
	 * We want to have a couple of commands here, an init routine which will do
	 * the actually socket horsework, and some check commands as necessary.
	 */
	if (argc < 2)
	{
		return(TCL_OK);
	}
	if (strcmp(argv[1], "init") == 0) {
		/*
		 * Build a socket for control connections. Socket is UDP, works best
		 * effort with the sendto() and recvfrom() options.
		 * THIS HAS BEEN MOVED TO THE ABOVE controlAPIinit() routines.
		 */
	} else if (strcmp(argv[1], "checkRequests") == 0) {
		/*
		 * This will be used for "busy accept()" if signalling does not 
		 * operate as anticipated.
		 */
	}
}

